Documentation
¶
Overview ¶
staacccccck
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RootModel ¶
type RootModel struct {
States StateStack
Client *api.TripClient
OriginID string
DestinationID string
Sidebar *flexbox.Cell
Main *flexbox.Cell
// contains filtered or unexported fields
}
func InitialiseRootModel ¶
func InitialiseRootModel() (m *RootModel)
type StateStack ¶
type StateStack struct {
// contains filtered or unexported fields
}
func (*StateStack) Pop ¶
func (s *StateStack) Pop() AppState
"Go back" - set the previous state of the app as the current Prevents user from showing a state before the welcome
func (*StateStack) Push ¶
func (s *StateStack) Push(state AppState)
Set state as the current app state
func (*StateStack) Size ¶
func (s *StateStack) Size() int
see how many states currently are on the stack
Click to show internal directories.
Click to hide internal directories.